local band = _G.bit.band
local pairs = _G.pairs
local select = _G.select
local format = _G.string.format
local GetLocale = _G.GetLocale
local GetSpellInfo = _G.GetSpellInfo
local UnitClass = _G.UnitClass
local CreateFrame = _G.CreateFrame
local close = _G.FONT_COLOR_CODE_CLOSE
local green = _G.GREEN_FONT_COLOR_CODE
local red = _G.RED_FONT_COLOR_CODE
local rt1 = _G.COMBATLOG_OBJECT_RAIDTARGET1
local rtmask = _G.COMBATLOG_OBJECT_SPECIAL_MASK
local friendly = _G.COMBATLOG_OBJECT_REACTION_FRIENDLY
local outsider = _G.COMBATLOG_OBJECT_AFFILIATION_OUTSIDER
local iconlist = _G.ICON_LIST
local hexformat = "|cff%02x%02X%02x"
local iconformat = "%s0|t"
local actionformat = "'s %s"

local prefix, cc, md

if GetLocale() == "enUS" then
	prefix = "|cffffff7fCrybaby:|r " 
	cc = prefix.."%s on %s%s%s"..close.." removed by %s%s%s"..close.."%s"
	md = prefix.."%s%s%s"..close.." cast %s on %s%s%s"..close
end



local spells = {
	(GetSpellInfo(118)), -- 118 Polymorph
	(GetSpellInfo(9484)), -- 9484 Shackle Undead
	(GetSpellInfo(2637)), -- 2637 Hibernate
	(GetSpellInfo(14309)), -- 14309 Freezing Trap Effect
	(GetSpellInfo(6358)), -- 6358 Seduction
	(GetSpellInfo(6770)), -- 6770 Sap
	}

local function getcolor(name)
	local class = name and (select(2, UnitClass(name)))
	local color = class and _G["RAID_CLASS_COLORS"][class]
	local hex = color and hexformat:format(color.r*255, color.g*255, color.b*255)
	return hex or nil
end

local function geticon(flag)
	local number 

	if band(flag, rtmask) ~= 0 then
		for i=1,8 do
			local mask = rt1 * (2 ^ (i - 1))
			local mark = (band(flag, mask) == mask)
			if mark then number = i end
		end
	end

	if not number then return "" end

	local icon = rt1 * (number ^ (number - 1))
	local path = iconlist[number]
	local ugly = iconformat:format(path)
	return ugly
end

local f = CreateFrame("Frame")
f:Hide()
f:SetScript("OnEvent", function(this, event, timestamp, subevent, srcGUID, src, srcFlags, dstGUID, dst, dstFlags, spellID, spell, spellSchool, extraID, extra, extraSchool, auratype)
	if subevent == "SPELL_AURA_BROKEN_SPELL" or subevent == "SPELL_AURA_BROKEN" then 
		if band(dstFlags, friendly) == 0 then
			for k,v in pairs(spells) do
				if v == spell then
					local srccolor = getcolor(src) or green
					local dstcolor = getcolor(dst) or red
					local srcicon = geticon(srcFlags) or ""
					local dsticon = geticon(dstFlags) or ""
					local breaker = src and src or "Unknown"
					local action = extra and (actionformat:format(extra)) or "" 
					print(cc:format(spell, dsticon, dstcolor, dst, srcicon, srccolor, breaker, action))
					break
				end
			end
		end
	elseif (subevent == "SPELL_CAST_SUCCESS" and (spellID == 34477 or spellID == 57934)) then
		if band(dstFlags, outsider) == 0 then
			local srccolor = getcolor(src) or red
			local dstcolor = getcolor(dst) or green
			local srcicon = geticon(srcFlags) or ""
			local dsticon = geticon(dstFlags) or ""
			print(md:format(srcicon, srccolor, src, spell, dsticon, dstcolor, dst))
		end
	end
end)
f:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
